@@ -4,7 +4,6 @@ import random
 import string
 import subprocess
 import tempfile
-import unittest
 import os
 
 from pulpcore.client.pulp_ansible import (
@@ -15,14 +14,15 @@ from pulpcore.client.pulp_ansible import (
     RepositoriesAnsibleApi,
     RepositoriesAnsibleVersionsApi,
 )
-from pulp_smash.pulp3.bindings import monitor_task
-from pulp_smash.pulp3.utils import delete_orphans, gen_distribution, gen_repo
+from pulp_smash.pulp3.bindings import delete_orphans, monitor_task, PulpTestCase
+from pulp_smash.pulp3.utils import gen_distribution, gen_repo
+from pulp_smash.utils import http_get, uuid4
 
 from pulp_ansible.tests.functional.utils import gen_ansible_client, wait_tasks
 from pulp_ansible.tests.functional.utils import set_up_module as setUpModule  # noqa:F401
 
 
-class InstallCollectionTestCase(unittest.TestCase):
+class InstallCollectionTestCase(PulpTestCase):
     """Test whether ansible-galaxy can upload a Collection to Pulp."""
 
     @classmethod
@@ -99,12 +99,16 @@ class InstallCollectionTestCase(unittest.TestCase):
         collections = self.collections_v3api.list(distribution.base_path)
         self.assertEqual(collections.meta.count, 0)
 
-        colletion_path = os.path.join(
-            os.getcwd(), "pulp_ansible/tests/assets/collections/pulp-testing_asset-1.0.0.tar.gz"
-        )
+        temp_path = f"/tmp/{uuid4()}"
+        subprocess.run(f"mkdir -p {temp_path}".split())
+
+        content = http_get("https://galaxy.ansible.com/download/pulp-squeezer-0.0.9.tar.gz")
+        collection_path = f"{temp_path}/pulp-squeezer-0.0.9.tar.gz"
+        with open(collection_path, "wb") as f:
+            f.write(content)
 
         cmd = "ansible-galaxy collection publish -c -s {} {}".format(
-            distribution.client_url, colletion_path
+            distribution.client_url, collection_path
         )
         subprocess.run(cmd.split())
         wait_tasks()
@@ -117,7 +121,7 @@ class InstallCollectionTestCase(unittest.TestCase):
         self.assertEqual(repo_version.number, 1)  # We uploaded 1 collection
 
         version = self.collections_versions_v3api.read(
-            "testing_asset", "pulp", distribution.base_path, "1.0.0"
+            "squeezer", "pulp", distribution.base_path, "0.0.9"
         )
 
-        self.assertEqual(version.requires_ansible, ">=2.9.10,<2.11")
+        self.assertEqual(version.requires_ansible, ">=2.8")
